==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_fields/TRADERATEDATA_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour TRADERATEDATA_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TRADERATEDATA_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADERATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADERATESTARTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADERATEENDDATE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TRADERATEDATA_Type", propOrder = {
    "traderate",
    "traderatestartdate",
    "traderateenddate"
})
public class TRADERATEDATA_Type {

    @XmlElement(name = "TRADERATE")
    protected AMOUNT traderate;
    @XmlElement(name = "TRADERATESTARTDATE")
    protected DATETIME traderatestartdate;
    @XmlElement(name = "TRADERATEENDDATE")
    protected DATETIME traderateenddate;

    /**
     * Obtient la valeur de la propriété traderate.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getTRADERATE() {
        return traderate;
    }

    /**
     * Définit la valeur de la propriété traderate.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setTRADERATE(AMOUNT value) {
        this.traderate = value;
    }

    /**
     * Obtient la valeur de la propriété traderatestartdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTRADERATESTARTDATE() {
        return traderatestartdate;
    }

    /**
     * Définit la valeur de la propriété traderatestartdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTRADERATESTARTDATE(DATETIME value) {
        this.traderatestartdate = value;
    }

    /**
     * Obtient la valeur de la propriété traderateenddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTRADERATEENDDATE() {
        return traderateenddate;
    }

    /**
     * Définit la valeur de la propriété traderateenddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTRADERATEENDDATE(DATETIME value) {
        this.traderateenddate = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/TRADERATEDATA_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for TRADERATEDATA_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TRADERATEDATA_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADERATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADERATESTARTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADERATEENDDATE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TRADERATEDATA_Type", propOrder = {
    "traderate",
    "traderatestartdate",
    "traderateenddate"
})
public class TRADERATEDATA_Type {

    @XmlElement(name = "TRADERATE")
    protected AMOUNT traderate;
    @XmlElement(name = "TRADERATESTARTDATE")
    protected DATETIME traderatestartdate;
    @XmlElement(name = "TRADERATEENDDATE")
    protected DATETIME traderateenddate;

    /**
     * Gets the value of the traderate property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getTRADERATE() {
        return traderate;
    }

    /**
     * Sets the value of the traderate property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setTRADERATE(AMOUNT value) {
        this.traderate = value;
    }

    /**
     * Gets the value of the traderatestartdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTRADERATESTARTDATE() {
        return traderatestartdate;
    }

    /**
     * Sets the value of the traderatestartdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTRADERATESTARTDATE(DATETIME value) {
        this.traderatestartdate = value;
    }

    /**
     * Gets the value of the traderateenddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTRADERATEENDDATE() {
        return traderateenddate;
    }

    /**
     * Sets the value of the traderateenddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTRADERATEENDDATE(DATETIME value) {
        this.traderateenddate = value;
    }

}
